@@ -63,6 +63,7 @@ from sollol.llama_cpp_rpc import LlamaCppDistributedCluster, LlamaCppRPCClient
 from sollol.unified_dashboard import UnifiedDashboard, run_unified_dashboard
 from sollol.distributed_tracing import DistributedTracer, get_tracer
 from sollol.dashboard_client import DashboardClient
+from sollol.network_observer import NetworkObserver, get_observer
 
 # Distributed execution
 from sollol.execution import AsyncDistributedExecutor, DistributedExecutor
@@ -77,7 +78,7 @@ from sollol.rpc_registry import RPCBackendRegistry
 # Legacy support
 from sollol.sollol import SOLLOL
 
-__version__ = "0.9.17"
+__version__ = "0.9.24"
 __all__ = [
     # Core
     "OllamaPool",
@@ -95,6 +96,8 @@ __all__ = [
     "DistributedTracer",
     "get_tracer",
     "DashboardClient",
+    "NetworkObserver",
+    "get_observer",
     # Distributed execution
     "DistributedExecutor",
     "AsyncDistributedExecutor",
