@@ -218,19 +218,18 @@ class RayHybridRouter:
         if self.enable_distributed:
             if not ray.is_initialized():
                 logger.info("🚀 Initializing Ray for distributed RPC coordination")
+
+                # Disable Ray memory monitor using the correct Ray 2.x method
+                import os
+                # Set monitor refresh to 0 to disable memory monitoring
+                os.environ['RAY_memory_monitor_refresh_ms'] = '0'
+
                 ray.init(
                     ignore_reinit_error=True,
                     dashboard_host="0.0.0.0",
                     dashboard_port=8265,
                     include_dashboard=True,
-                    # Aggressive memory limits to prevent OOM kills in CLI apps
-                    object_store_memory=256 * 1024 * 1024,  # 256MB object store (minimal)
-                    _memory=1 * 1024 * 1024 * 1024,  # 1GB total per worker
                     num_cpus=1,  # Single CPU to minimize workers
-                    _system_config={
-                        "automatic_object_spilling_enabled": True,  # Spill to disk instead of OOM
-                        "max_io_workers": 1,  # Minimal I/O workers
-                    },
                 )
                 logger.info("📊 Ray dashboard available at http://localhost:8265")
 
